signers_keylet

Function signers_keylet 

pub fn signers_keylet(account_id: &AccountID) -> Result<KeyletBytes>
Generates a signer entry keylet for a given XRP Ledger account.

signer entry keylets are used to reference signer entries in the XRP Ledger’s state data. This function uses the generic create_keylet_from_host_call helper to manage the FFI interaction.

Arguments

  • account_id - Reference to an AccountID representing the XRP Ledger account

Returns

  • Result<KeyletBytes> - On success, returns a 32-byte signer entry keylet. On failure, returns an Error with the corresponding error code.

Safety

This function makes unsafe FFI calls to the host environment through the host::signers_keylet function, though the unsafe code is contained within the closure passed to create_keylet_from_host_call.

Example


use xrpl_wasm_stdlib::core::types::account_id::AccountID;
use xrpl_wasm_stdlib::core::keylets::signers_keylet;
use xrpl_wasm_stdlib::host::trace::{DataRepr, trace_data, trace_num};
fn main() -> Result<(), Box<dyn std::error::Error>> {
  let account:AccountID = AccountID::from(
    *b"\xd5\xb9\x84VP\x9f \xb5'\x9d\x1eJ.\xe8\xb2\xaa\x82\xaec\xe3"
  );
  match signers_keylet(&account){
    xrpl_wasm_stdlib::host::Result::Ok(keylet) => {
      let _ = trace_data("Generated keylet", &keylet, DataRepr::AsHex);
    }
    xrpl_wasm_stdlib::host::Result::Err(e) => {
      let _ = trace_num("Error assembling keylet", e.code() as i64);
    }
  }
  Ok(())
}